var MzClock = new Class({
	Implements: [Events,Options],
	
	options: {
		width: 500,
		height: 500,
	},
	
	initialize: function(container, options) {
		this.setOptions(options);
		this.container = $(container);
		if (!this.container) {
			return;
		}
		this.create();
		if (this.ctx) {
			this.redraw.periodical(200, this);
		}
	},
	
	create: function() {
		this.canvas = new Element('canvas', {'width': this.options.width, 
											 'height': this.options.height});
		if (!this.canvas) {
			return;
		}
		
		this.container.appendChild(this.canvas);
		this.ctx = this.canvas.getContext("2d");
		if (!this.ctx) {
			return;
		}
	},
	
	redraw: function() {
		this.ctx.save();
		this.ctx.clearRect(0, 0, this.options.width, this.options.height);
		this.ctx.translate(this.options.width/2, this.options.height/2);
		this.ctx.scale(0.003 * this.options.width, 0.003 * this.options.height);
		this.ctx.rotate(-Math.PI/2);
		this.ctx.strokeStyle = '#000000';
		this.ctx.fillStyle = '#ffffff';
		this.ctx.lineWidth = 4;
		this.ctx.lineCap = "round";
		
		this.drawHourMarks();
		this.drawMinuteMarks();
		this.drawPointers();
		
		this.drawOutline();
		this.ctx.restore();
	},
	
	drawOutline: function() {
		this.ctx.beginPath();
		this.ctx.lineWidth = 14;
		this.ctx.strokeStyle = '#325FA2';
		this.ctx.arc(0,0,142,0,Math.PI*2,true);
		this.ctx.stroke();
	},
	
	drawHourMarks: function() {
		// Hour marks
		this.ctx.save();
		for (var i=0;i<12;i++){
		this.ctx.beginPath();
		this.ctx.rotate(Math.PI/6);
		this.ctx.moveTo(100,0);
		this.ctx.lineTo(120,0);
		this.ctx.stroke();
		}
		this.ctx.restore();
	},
	
	drawMinuteMarks: function() {
		// Minute marks
		this.ctx.save();
		this.ctx.lineWidth = 5;
		for (i=0;i<60;i++) {
			if (i%5!=0) {
				this.ctx.beginPath();
				this.ctx.moveTo(117,0);
				this.ctx.lineTo(120,0);
				this.ctx.stroke();
			}
			this.ctx.rotate(Math.PI/30);
		}
		this.ctx.restore();
	},
	
	drawPointers: function() {
		var now = new Date();
		var sec  = now.getSeconds();
		var min  = now.getMinutes();
		var hour = now.getHours();
		
		this.drawHourPointer(hour, min, sec);
		this.drawMinutePointer(min, sec);
		this.drawSecondPointer(sec);
	},
	
	drawHourPointer: function(h, m, s) {
		h = h >= 12 ? h-12 : h;
		this.ctx.fillStyle = '#000000';

		// Hours pointer
		this.ctx.save();
		this.ctx.rotate(h*(Math.PI/6) + (Math.PI/360)*m + (Math.PI/21600)*s);
		this.ctx.lineWidth = 14;
		this.ctx.beginPath();
		this.ctx.moveTo(-20,0);
		this.ctx.lineTo(80,0);
		this.ctx.stroke();
		this.ctx.restore();
	},
	
	drawMinutePointer: function(m, s) {
		// Minutes pointer
		this.ctx.save();
		this.ctx.rotate( (Math.PI/30)*m + (Math.PI/1800)*s )
		this.ctx.lineWidth = 7;
		this.ctx.beginPath();
		this.ctx.moveTo(-28,0);
		this.ctx.lineTo(112,0);
		this.ctx.stroke();
		this.ctx.restore();
	},
	
	drawSecondPointer: function(s) {
		// Seconds pointer
		this.ctx.save();
		this.ctx.rotate(s * Math.PI/30);
		this.ctx.strokeStyle = "#D40000";
		this.ctx.fillStyle = "#D40000";
		this.ctx.lineWidth = 4;
		this.ctx.beginPath();
		this.ctx.moveTo(-30,0);
		this.ctx.lineTo(105,0);
		this.ctx.stroke();
		
		// circle in the middle
		this.ctx.lineWidth = 4;
		this.ctx.beginPath();
		this.ctx.arc(0,0,6,0,Math.PI*2,true);
		this.ctx.fill();
		
		this.ctx.restore();
	}
});
